%global with_fastcgi   0
%global with_memcached 0
%global with_log4cpp   0
%global with_log4shib  1

Name: shibboleth-sp
Version: 3.4.1
Release: 1%{?dist}
Summary: Open source system for attribute-based Web SSO
License: Apache-2.0
Vendor: Shibboleth Consortium
URL: http://shibboleth.net/
Source http://shibboleth.net/downloads/service-provider/%{name}-%{version}.tar.bz2
BuildRequires: gcc-c++ gdb
BuildRequires: doxygen
BuildRequires: boost-devel >= 1.32.0
BuildRequires: httpd-devel
BuildRequires: krb5-devel
BuildRequires: systemd-devel
BuildRequires: unixODBC-devel
%if 0%{?with_fastcgi}
BuildRequires: fcgi-devel
%endif
%if 0%{?with_memcached}
BuildRequires: libmemcached-devel
%endif
%if 0%{?with_log4cpp}
BuildRequires: log4cpp-devel >= 1.0
%endif
%if 0%{?with_log4shib}
BuildRequires: log4shib-devel >= 2.0.1
%endif
BuildRequires: openssl-devel
BuildRequires: xerces-c-devel >= 3.2.3
BuildRequires: xml-security-c-devel >= 2.0.4
BuildRequires: xmltooling-devel >= 3.2.3
BuildRequires: xmltooling-schemas >= 3.2.3
BuildRequires: opensaml-devel >= 3.2.1
BuildRequires: opensaml-schemas >= 3.2.1
Requires: hostname
Requires: openssl
Requires(pre): shadow-utils
Requires(post): chkconfig
Requires(preun): chkconfig, initscripts

%{!?_tmpfilesdir:%global _tmpfilesdir /usr/lib/tmpfiles.d}

%define runuser shibd

%description
Shibboleth is a Web Single Sign-On implementations based on OpenSAML
that supports multiple protocols, federated identity, and the extensible
exchange of rich attributes subject to privacy controls.

This package contains the Shibboleth Service Provider runtime libraries,
daemon, default plugins, and Apache module(s).

%package devel
Summary: Shibboleth Development Headers
Requires: %{name} = %{version}-%{release}
%if 0%{?with_log4cpp}
BuildRequires: log4cpp-devel >= 1.0
%endif
%if 0%{?with_log4shib}
BuildRequires: log4shib-devel >= 2.0.1
%endif
Requires: xerces-c-devel >= 3.2.3
Requires: xml-security-c-devel >= 2.0.4
Requires: xmltooling-devel >= 3.2.1
Requires: opensaml-devel >= 3.2.1

%description devel
Shibboleth is a Web Single Sign-On implementations based on OpenSAML
that supports multiple protocols, federated identity, and the extensible
exchange of rich attributes subject to privacy controls.

This package includes files needed for development with Shibboleth.

%prep
%setup -n %{name}-%{version}

%build
%configure %{?_with_fastcgi} %{?_with-memcached}
%{__make} pkgdocdir=%{_pkgdocdir}

%install
%{__make} install NOKEYGEN=1 DESTDIR=%{buildroot} pkgdocdir=%{_pkgdocdir}

# Plug the SP into the built-in Apache.
%{__mkdir} -p %{buildroot}%{_sysconfdir}/httpd/conf.d
%{__cp} -p %{buildroot}%{_sysconfdir}/shibboleth/apache24.config %{buildroot}%{_sysconfdir}/httpd/conf.d/shib.conf 

# Generate the systemd file.
%{__mkdir} -p %{buildroot}%{_unitdir}
cat > %{buildroot}%{_unitdir}/shibd.service <<EOF
[Unit]
Description=Shibboleth Service Provider Daemon
Documentation=https://wiki.shibboleth.net/confluence/display/SP3/Home
After=network-online.target
Before=httpd.service

[Service]
Type=notify
NotifyAccess=main
User=%{runuser}
ExecStart=%{_sbindir}/shibd -f -F
StandardInput=null
StandardOutput=null
StandardError=journal
TimeoutStopSec=1m
TimeoutStartSec=5m
Restart=on-failure
RestartSec=30s

[Install]
WantedBy=multi-user.target
EOF

# Get run directory created at boot time.
%{__mkdir} -p %{buildroot}%{_tmpfilesdir}
cat > %{buildroot}%{_tmpfilesdir}/%{name}.conf <<EOF
d /run/%{name} 755 %{runuser} %{runuser} -
EOF

%check
%{__make} check

%pre
getent group %{runuser} >/dev/null || groupadd -r %{runuser}
getent passwd %{runuser} >/dev/null || useradd -r -g %{runuser} \
	-d  %{_localstatedir}/run/shibboleth -s /sbin/nologin -c "Shibboleth SP daemon" %{runuser}
exit 0

%post
/sbin/ldconfig

# Generate two keys on new installs.
if [ $1 -eq 1 ] ; then
	cd %{_sysconfdir}/shibboleth
	/bin/sh ./keygen.sh -b -n sp-signing -u %{runuser} -g %{runuser}
	/bin/sh ./keygen.sh -b -n sp-encrypt -u %{runuser} -g %{runuser}
fi

if [ $1 -gt 1 ] ; then
	# On Red Hat with shib.conf installed, clean up old Alias commands
	# by pointing them at new version-independent /usr/share/share tree.
	# Any Aliases we didn't create we assume are custom files.
	# This is to accomodate making shib.conf a noreplace config file.
	%{__sed} -i "s/\/usr\/share\/doc\/shibboleth\(\-\(.\)\{1,\}\)\{0,1\}\/main\.css/\/usr\/share\/shibboleth\/main.css/g" %{_sysconfdir}/httpd/conf.d/shib.conf
	%{__sed} -i "s/\/usr\/share\/doc\/shibboleth\(\-\(.\)\{1,\}\)\{0,1\}\/logo\.jpg/\/usr\/share\/shibboleth\/logo.jpg/g" %{_sysconfdir}/httpd/conf.d/shib.conf
fi

# Initial prep for systemd
%systemd_post shibd.service
if [ $1 -gt 1 ] ; then
	%{_bindir}/systemctl daemon-reload
fi

%preun
# On final removal, stop shibd and remove service, restart Apache if running.
%systemd_preun shibd.service
%{_bindir}/systemctl condrestart httpd > /dev/null 2>&1 || :

%postun
/sbin/ldconfig
# On upgrade, restart components if they're already running.
%systemd_postun_with_restart shibd.service
%{_bindir}/systemctl condrestart httpd > /dev/null 2>&1 || :

%files
%defattr(-,root,root,-)
%attr(0444,-,-) %{_unitdir}/shibd.service
%attr(0444,-,-) %{_tmpfilesdir}/%{name}.conf
%{_sbindir}/shibd
%{_bindir}/mdquery
%{_bindir}/resolvertest
%{_libdir}/libshibsp.so.*
%{_libdir}/libshibsp-lite.so.*
%exclude %{_libdir}/*.la
%dir %{_libdir}/shibboleth
%{_libdir}/shibboleth/*.so
%exclude %{_libdir}/shibboleth/*.la
%{?_with_fastcgi:%{_libdir}/shibboleth/shibauthorizer}
%{?_with_fastcgi:%{_libdir}/shibboleth/shibresponder} 
%attr(0750,%{runuser},%{runuser}) %dir %{_localstatedir}/log/shibboleth
%attr(0755,%{runuser},%{runuser}) %dir %{_localstatedir}/cache/shibboleth
%dir %{_datadir}/xml/shibboleth
%{_datadir}/xml/shibboleth/*
%dir %{_datadir}/shibboleth
%{_datadir}/shibboleth/*
%dir %{_sysconfdir}/shibboleth
%config(missingok, noreplace) %{_sysconfdir}/shibboleth/shibboleth2.xml
%config(noreplace) %{_sysconfdir}/shibboleth/attribute-map.xml
%config(noreplace) %{_sysconfdir}/shibboleth/attribute-policy.xml
%config(noreplace) %{_sysconfdir}/shibboleth/example-metadata.xml
%config(noreplace) %{_sysconfdir}/shibboleth/protocols.xml
%config(noreplace) %{_sysconfdir}/shibboleth/security-policy.xml
%config(noreplace) %{_sysconfdir}/shibboleth/*.html
%config(noreplace) %{_sysconfdir}/shibboleth/*.logger
%config(noreplace) %{_sysconfdir}/httpd/conf.d/shib.conf
%{_tmpfilesdir}/%{name}.conf
%{_sysconfdir}/shibboleth/example-shibboleth2.xml
%{_sysconfdir}/shibboleth/*.dist
%{_sysconfdir}/shibboleth/apache*.config
%{_sysconfdir}/shibboleth/shibd-*
%attr(0755,root,root) %{_sysconfdir}/shibboleth/keygen.sh
%attr(0755,root,root) %{_sysconfdir}/shibboleth/metagen.sh
%attr(0755,root,root) %{_sysconfdir}/shibboleth/seckeygen.sh
%doc %{_pkgdocdir}
%exclude %{_pkgdocdir}/api

%files devel
%defattr(-,root,root,-)
%{_includedir}/*
%{_libdir}/libshibsp.so
%{_libdir}/libshibsp-lite.so
%{_libdir}/pkgconfig/*.pc
%doc %{_pkgdocdir}/api

%changelog
* Tue Apr 04 2023 Jean-Marc Liger <ligenix@iscp.fr> - 3.4.1-1
- Update to 3.4.1

* Tue Dec 13 2022 Jean-Marc Liger <ligenix@iscp.fr> - 3.4.0-1
- Update to 3.4.0

* Sat Aug 27 2022 Jean-Marc Liger <ligenix@iscp.fr> - 3.3.0-2
- Correct also with/without macros in devel

* Fri Aug 26 2022 Jean-Marc Liger <ligenix@iscp.fr> - 3.3.0-1
- Update to 3.3.0
- Switch to with/without macros

* Tue Oct 12 2021 Jean-Marc Liger <ligenix@iscp.fr> - 3.2.2-4
- Switch to %ldconfig_scriptlets
- Rebuild for COPR EL8

* Thu Apr 22 2021 Scott Cantor <cantor.2@osu.edu> - 3.2.2-1|3.1
- Fix devel dependency versions

* Tue Dec 1 2020 Scott Cantor <cantor.2@osu.edu> - 3.2.0-1
- Version and lib bump

* Mon Feb 3 2020 Scott Cantor <cantor.2@osu.edu> - 3.1.0-1
- Version and lib bump
- Add hostname dependency for keygen script

* Mon Sep 30 2019 Scott Cantor <cantor.2@osu.edu> - 3.0.4-1
- CentOS 8 cleanup

* Mon Apr 30 2018 Scott Cantor <cantor.2@osu.edu> - 3.0.0-1
- Bump dependency versions
- Require updated libraries across the board
- Generate two keys on new installs

* Tue May 03 2016 Scott Cantor <cantor.2@osu.edu> - 2.6.0-1
- Bump opensaml dependency version
- Bump max wait time for shibd systemd unit file

* Thu Jul 23 2015 Scott Cantor <cantor.2@osu.edu> - 2.5.5-2
- Fix use of /var/run/shibboleth on newer tmpfs platforms

* Thu Jul 2 2015 Scott Cantor <cantor.2@osu.edu> - 2.5.5-1
- Revamp with systemd support for RH/CentOS 7+ and SUSE 12.1+

* Mon Mar 9 2015 Scott Cantor <cantor.2@osu.edu> - 2.5.4-1
- Add Amazon VM support
- Add a separate native logging directory
- Remove hard-coded init.d usage
- Switch to bz2 sources to prevent future issues with SuSE

* Mon Nov 17 2014 Scott Cantor <cantor.2@osu.edu> - 2.5.3-2
- Add libtool dep for OpenSUSE 13
- Remove /var/run/shibboleth for OpenSUSE 13

* Tue May 13 2014 Ian Young <ian@iay.org.uk> - 2.5.3-1.2
- Update package dependencies for RHEL/CentOS 7
- Fix bogus dates in changelog

* Sat Jun 8 2013   Scott Cantor  <cantor.2@osu.edu>  - 2.5.2-1
- Add --with-gssapi using MIT K5 by default

* Tue Sep 25 2012  Scott Cantor  <cantor.2@osu.edu>  - 2.5.1-1
- Merge back various changes used in released packages
- Prep for 2.5.1 by pulling extra restart out

* Tue Aug 7 2012  Scott Cantor  <cantor.2@osu.edu>  - 2.5.0-2
- Changed package name back to shibboleth because of upgrade bugs
- Put back extra restart for this release only.

* Thu Mar 1 2012  Scott Cantor  <cantor.2@osu.edu>  - 2.5.0-1
- Move logo and stylesheet to version-independent tree
- Make shib.conf noreplace
- Post-fixup of Alias commands in older shib.conf
- Changes to run shibd as non-root shibboleth user
- Move init customizations to /etc/sysconfig/shibd
- Copy shibd restart for Red Hat to postun
- Add boost-devel dependency
- Build memcache plugin on RH6
- Add cachedir to install
- Add Apache 2.4 to install

* Sun Jun 26 2011  Scott Cantor  <cantor.2@osu.edu>  - 2.4.3-1
- Log files shouldn't be world readable.
- Explicit requirement for libcurl-openssl on RHEL6
- Uncomment LD_LIBRARY_PATH in init script for RHEL6 
- Remove rpath from binaries for RHEL6

* Fri Dec 25 2009  Scott Cantor  <cantor.2@osu.edu>  - 2.4-1
- Update dependencies.

* Mon Nov 23 2009 Scott Cantor  <cantor.2@osu.edu>  - 2.3.1-1
- Reset revision for 2.3.1 release

* Wed Aug 19 2009 Scott Cantor  <cantor.2@osu.edu>  - 2.2.1-2
- SuSE init script changes
- Restart Apache on removal, not just upgrade
- Fix scriptlet exit values when Apache is stopped

* Mon Aug 10 2009 Scott Cantor  <cantor.2@osu.edu>  - 2.2.1-1
- Doc handling changes
- SuSE init script

* Tue Aug 4 2009 Scott Cantor  <cantor.2@osu.edu>  - 2.2.1-1
- Initial version for 2.2.1, with shibd/httpd restart on upgrade

* Thu Jun 25 2009 Scott Cantor  <cantor.2@osu.edu>  - 2.2-3
- Add additional cleanup to posttrans fix

* Tue Jun 23 2009 Scott Cantor  <cantor.2@osu.edu>  - 2.2-2
- Reverse without_builtinapache macro test
- Fix init script handling on Red Hat to handle upgrades

* Wed Dec 3 2008  Scott Cantor  <cantor.2@osu.edu>  - 2.2-1
- Bump minor version.
- Make keygen.sh executable.
- Fixing SUSE Xerces dependency name.
- Optionally package shib.conf.

* Tue Jun 10 2008  Scott Cantor  <cantor.2@osu.edu>  - 2.1-1
- Change shib.conf handling to treat as config file.

* Mon Mar 17 2008  Scott Cantor  <cantor.2@osu.edu>  - 2.0-6
- Official release.

* Fri Jan 18 2008  Scott Cantor  <cantor.2@osu.edu>  - 2.0-5
- Release candidate 1.

* Sun Oct 21 2007 Scott Cantor  <cantor.2@osu.edu>  - 2.0-4
- libexec -> lib/shibboleth changes
- Added doc subpackage

* Thu Aug 16 2007 Scott Cantor  <cantor.2@osu.edu>  - 2.0-3
- First public beta.

* Fri Jul 13 2007 Scott Cantor	<cantor.2@osu.edu>  - 2.0-2
- Second alpha release.

* Sun Jun 10 2007 Scott Cantor	<cantor.2@osu.edu>  - 2.0-1
- First alpha release.

* Mon Oct 2 2006 Scott Cantor	<cantor.2@osu.edu>  - 1.3-11
- Applied fix for secadv 20061002
- Fix for metadata loader loop

* Thu Jun 15 2006 Scott Cantor  <cantor.2@osu.edu>  - 1.3-10
- Applied fix for sec 20060615

* Sat Apr 15 2006 Scott Cantor  <cantor.2@osu.edu>  - 1.3-9
- Misc. patches, SuSE, Apache 2.2, gcc 4.1, and 64-bit support

* Mon Jan 9 2006 Scott Cantor  <cantor.2@osu.edu>  - 1.3-8
- Applied new fix for secadv 20060109

* Tue Nov 8 2005 Scott Cantor  <cantor.2@osu.edu>  - 1.3-7
- Applied new fix for secadv 20050901 plus rollup

* Fri Sep 23 2005 Scott Cantor  <cantor.2@osu.edu>  - 1.3-6
- Minor patches and default config changes
- pidfile patch
- Fix shib.conf creation
- Integrated init.d script
- Prevent replacement of config files

* Thu Sep 1 2005  Scott Cantor  <cantor.2@osu.edu>  - 1.3-5
- Applied fix for secadv 20050901 plus rollup of NSAPI fixes

* Sun Apr 24 2005  Scott Cantor  <cantor.2@osu.edu>  - 1.3-1
- Updated test programs and location of schemas.
- move siterefresh to to sbindir

* Fri Apr  1 2005  Derek Atkins  <derek@ihtfp.com>  - 1.3-1
- Add selinux-targeted-policy package
- move shar to sbindir

* Tue Oct 19 2004  Derek Atkins  <derek@ihtfp.com>  - 1.2-1
- Create SPEC file based on various versions in existence.
